#======================================
# Air pollution data
#======================================

# This script reads and transforms the raw air pollution data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: PM2.5 air pollution, population exposed to levels exceeding WHO guideline value (% of total), from world bank database

setwd(data_wd)
#### Read data ####
data <- read_excel("AIR_POLLUTION_ORIG.xls", sheet = "Data", col_names = TRUE, col_types = NULL,skip = 3,na="")

# Fix names - Splits the names and extracts only the numeric year
#colnames(data)[4:ncol(data)] <- colsplit(colnames(data)[4:ncol(data)], split="SOC.", c("TRASH","YEAR"))[,2]

# Gather to country-year units and give the new variable/columnname AIR_POLLUTION
tdata <- gather(data,YEAR,AIR_POLLUTION, `1960`:ncol(data))

data2 <- data.frame(row.names = c(1:nrow(tdata)))
data2$COUNTRY <- tdata$`Country Name`
data2$ISO <- tdata$`Country Code`
data2$YEAR <- as.character(tdata$YEAR)
data2$AIR_POLLUTION <- tdata$AIR_POLLUTION

AIR_POLLUTION <- data2
rm(data,data2,tdata)

#### Bind to id_mat #### (Merging by ISO)

# Merging by ISO, so rename those that don't match
# ik denk niet dat er zijn die niet matchen...

# Merge
mdata <- merge(id_mat, AIR_POLLUTION, by.x = c("ISO3C","YEAR"), by.y = c("ISO","YEAR"), all.x=T) # all.x=T zorgt voor een left (outer) join, zodat alleen de jaartallen die in GCRI zitten (1998-2014) meegenomen workden

#### Missing values ####
# Impute using previous known values
mdata <- flp.impute(mdata, 1, 12)

# Rescale from 0 to 10 with possibility of swopping order high to low
mdata$AIR_POLLUTION <- scale010(mdata$AIR_POLLUTION,0) #direction == 0, no direction change

### Final dataset for further use ###

data <- subset(mdata,select = c("AIR_POLLUTION","YEAR","ISO3C"))

rm(mdata, AIR_POLLUTION)
save.image("../PROCESSED/AIR_POLLUTION.Rdata")