#======================================
# Biodiversity protection data
#======================================

# This script reads and transforms the raw Biodiversity protection data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: eco-region protection by CIESIN's Natural Resource Management Index. Developed by CIESIN, 
# this indicator assesses whether a country is protecting at least 10% of all of its biomes (e.g. deserts,
# forests, grasslands, aquatic, and tundra). It is designed to capture the comprehensiveness of a government???s 
# commitment to habitat preservation and biodiversity protection. World Wildlife Fund provide the underlying 
# biome data, and the United Nations Environment Program World Conservation Monitoring Center provide the 
# underlying data on protected areas.

setwd(data_wd)

## Variable constructions BIODIVERSITY_PROT ##
# Data
data <- read_excel("BIODIVERSITY_PROT_ORIG.xls", sheet = "raw data", col_names = TRUE, col_types = NULL,skip = 0)
data <- subset(data,select = c("CountryName","ISO3V10","ecoprot_06_raw","ecoprot_07_raw","ecoprot_08_raw","ecoprot_09_raw","ecoprot_10_raw","ecoprot_11_raw"))

# change columnnames create year-country data in 1 column
colnames(data)[3:8]<- c("2006","2007","2008","2009","2010","2011")
tdata <- gather(data,YEAR,BIODIVERSITY_PROT, `2006`:ncol(data))

data <- data.frame(row.names = c(1:nrow(tdata)))
data$COUNTRY <- tdata$`CountryName`
data$ISO <- tdata$`ISO3V10`
data$YEAR <- tdata$YEAR
data$BIODIVERSITY_PROT <- tdata$BIODIVERSITY_PROT
data$COUNTRY <- as.character(data$COUNTRY)
data$YEAR <- as.numeric(as.character(data$YEAR))
data$BIODIVERSITY_PROT <- as.numeric(as.character(data$BIODIVERSITY_PROT))

# Load ID matrix and merge to subset wanted info
mdata <- merge(id_mat, data, by.x = c("ISO3C","YEAR"), by.y = c("ISO","YEAR"), all.x=T)

# Impute first and last values if any are missing by repeating the first or last available data point
mdata <- flp.impute(mdata,1,12)

data <- subset(mdata, select = c("BIODIVERSITY_PROT","YEAR","ISO3C"))
rm(mdata,tdata)

# Rescale
data$BIODIVERSITY_PROT <- scale010(data$BIODIVERSITY_PROT,0)

save.image("../PROCESSED/BIODIVERSITY_PROT.Rdata")
