#======================================
# Fisheries data
#======================================

# This script reads and transforms the raw fisheries data into the Rdata file found in the folder PROCESSED_DATA

# the data contains:


setwd(data_wd)
#### Read data ####
data <- read_excel("EPI_FISHERIES_ORIG.xls", sheet = "FSOC - Fish Stocks", col_names = TRUE, col_types = NULL,skip = 0,na="-9999")

# Fix names - Splits the names and extracts only the numeric year
colnames(data)[4:ncol(data)] <- colsplit(colnames(data)[4:ncol(data)], split="SOC.", c("TRASH","YEAR"))[,2]

# Gather to country-year units
tdata <- gather(data,YEAR,FISH, `1950`:ncol(data))

data2 <- data.frame(row.names = c(1:nrow(tdata)))
data2$COUNTRY <- tdata$`country`
data2$ISO <- tdata$`iso`
data2$YEAR <- as.character(tdata$YEAR)
data2$FISH <- tdata$FISH

FISH <- data2
rm(data,data2,tdata)

#### Bind to id_mat #### (Merging by ISO)

# Merging by ISO, so rename those that don't match
# ik denk niet dat er zijn die niet matchen...

# Merge
mdata <- merge(id_mat, FISH, by.x = c("ISO3C","YEAR"), by.y = c("ISO","YEAR"), all.x=T) # all.x=T zorgt voor een left (outer) join, zodat alleen de jaartallen die in GCRI zitten meegenomen workden

#### Missing values ####
# Impute using previous known values
mdata <- flp.impute(mdata, 1, 12)

# Rescale from 0 to 10 where a higher FISH score = a lower normalized score
mdata$FISH <- scale010(mdata$FISH,0) #direction == 0, no direction change

### Final dataset for further use ###

data <- subset(mdata,select = c("FISH","YEAR","ISO3C"))

rm(mdata, FISH)
save.image("../PROCESSED/FISH.Rdata")