#======================================
# Natural disaster data
#======================================

# This script reads and transforms the raw natural disaster data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: total amount of people affected by a natural disaster. People requiring immediate 
# assistance during a period of emergency, i.e. requiring basic survival needs such as food, water, shelter, 
# sanitation and immediate medical assistance. The total affected is the sum of injured, affected and 
# homeless. Also includes biological disasters such as epidemics and widespread infections (EM-DAT: The 
# Emergency Events Database - Universit?? catholique de Louvain (UCL) - CRED, D. Guha-Sapir - www.emdat.be, 
# Brussels, Belgium)

setwd(data_wd)

#### Var construction - NAT_DISASTER ####
# Data
data <- read.csv('NAT_DISASTER_ORIG.csv')
data <- subset(data,select = c("iso","X.country_name","year","Total.affected"))

# Load ID matrix and merge to subset wanted info
mdata <- merge(id_mat, data, by.x = c("ISO3C","YEAR"), by.y = c("iso","year"), all.x=T)

# Impute first and last values if any are missing by repeating the first or last available data point
# mdata <- flp.impute(mdata,1,12)

# no impute here, fill in all empty space with 0! Any countries still left missing are scored 0
mdata$Total.affected[is.na(mdata$Total.affected)] <- 0
data <- subset(mdata, select = c("Total.affected","YEAR","ISO3C"))
rm(mdata)
colnames(data)[1]<- "NAT_DISASTER"

# Rescale
data$NAT_DISASTER <- scale010(data$NAT_DISASTER,0)

save.image("../PROCESSED/NAT_DISASTER.Rdata")
