#======================================
# Population density data
#======================================

# This script reads and transforms the raw population density data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: Population density (persons per square km), as of 1 July. United Nations population division

setwd(data_wd)
#### Read data ####
data <- read_excel("POPULATION_DENSITY_ORIG.xlsx", sheet = "ESTIMATES", col_names = TRUE, col_types = NULL,skip = 16,na="")

# Gather to country-year units and give the new variable/columnname POPULATION_DENSITY
tdata <- gather(data,YEAR,POPULATION_DENSITY, `1950`:ncol(data))

data2 <- data.frame(row.names = c(1:nrow(tdata)))
data2$COUNTRY <- tdata$"Region, subregion, country or area *"
data2$UNCODE <- tdata$"Country code"
data2$YEAR <- as.character(tdata$YEAR)
data2$POPULATION_DENSITY <- tdata$POPULATION_DENSITY

POPULATION_DENSITY <- data2
rm(data,data2,tdata)

#### Bind to id_mat #### (Merging by UNCODE)

# Merging by UNCODE, so rename those that don't match
# ik denk niet dat er zijn die niet matchen...

# Merge
mdata <- merge(id_mat, POPULATION_DENSITY, by.x = c("UN","YEAR"), by.y = c("UNCODE","YEAR"), all.x=T) # all.x=T zorgt voor een left (outer) join, zodat alleen de jaartallen die in GCRI zitten (1998-2014) meegenomen workden

#### Missing values ####
# Impute using previous known values
mdata <- flp.impute(mdata, 1, 12)

# Rescale from 0 to 10 with possibility of swopping order high to low
mdata$POPULATION_DENSITY <- scale010(mdata$POPULATION_DENSITY,0) #direction == 0, no direction change

### Final dataset for further use ###

data <- subset(mdata,select = c("POPULATION_DENSITY","YEAR","ISO3C"))

rm(mdata, POPULATION_DENSITY)
save.image("../PROCESSED/POPULATION_DENSITY.Rdata")