#======================================
# Resource rent data
#======================================

# This script reads and transforms the raw resource rent data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: Total natural resources rents (% of GDP), Total natural resources rents are the sum of oil rents, natural gas rents, coal rents (hard and soft), mineral rents, and forest rents.

setwd(data_wd)
#### Read data ####
data <- read_excel("RESOURCE_RENT_ORIG.xls", sheet = "Data", col_names = TRUE, col_types = NULL,skip = 3,na="")

# Fix names - Splits the names and extracts only the numeric year
#colnames(data)[4:ncol(data)] <- colsplit(colnames(data)[4:ncol(data)], split="SOC.", c("TRASH","YEAR"))[,2]

# Gather to country-year units and give the new variable/columnname RESOURCE_RENT
tdata <- gather(data,YEAR,RESOURCE_RENT, `1960`:ncol(data))

data2 <- data.frame(row.names = c(1:nrow(tdata)))
data2$COUNTRY <- tdata$`Country Name`
data2$ISO <- tdata$`Country Code`
data2$YEAR <- as.character(tdata$YEAR)
data2$RESOURCE_RENT <- tdata$RESOURCE_RENT

RESOURCE_RENT <- data2
rm(data,data2,tdata)

#### Bind to id_mat #### (Merging by ISO)

# Merging by ISO, so rename those that don't match
# ik denk niet dat er zijn die niet matchen...

# Merge
mdata <- merge(id_mat, RESOURCE_RENT, by.x = c("ISO3C","YEAR"), by.y = c("ISO","YEAR"), all.x=T) # all.x=T zorgt voor een left (outer) join, zodat alleen de jaartallen die in GCRI zitten (1998-2014) meegenomen workden

#### Missing values ####
# Impute using previous known values
mdata <- flp.impute(mdata, 1, 12)

# Rescale from 0 to 10 with possibility of swopping order high to low
mdata$RESOURCE_RENT <- scale010(mdata$RESOURCE_RENT,0) #direction == 0, no direction change

### Final dataset for further use ###

data <- subset(mdata,select = c("RESOURCE_RENT","YEAR","ISO3C"))

rm(mdata, RESOURCE_RENT)
save.image("../PROCESSED/RESOURCE_RENT.Rdata")