#======================================
# Soil degradation data
#======================================

# This script reads and transforms the raw soil degradation data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: average land degradation in GLASOD erosion degrees: The global survey on human-induced 
# soil degradation is the GLASOD (Global Assessment of Human-Induced Soil Degradation), prepared jointly by 
# ISRIC and UNEP during the 1980???s. From 0 (no degradation) to 4 (extreme) (FAOSTAT)

setwd(data_wd)

#### Var construction - SOIL_DEGR ####
# Data
data <- read.csv('SOIL_DEGR_ORIG.csv')
data <- subset(data,select = c("Country.Code","Country","Year","Value"))
data$"Value"[154]<- 4 # china china's value to the max, i.e. 4 since it had a value of 7,8 strangely enough...

# Load ID matrix and merge to subset wanted info
mdata <- merge(id_mat, data, by.x = c("FAO","YEAR"), by.y = c("Country.Code","Year"), all.x=T)

# Impute first and last values if any are missing by repeating the first or last available data point
mdata <- flp.impute(mdata,1,12)

data <- subset(mdata, select = c("Value","YEAR","ISO3C"))
rm(mdata)
colnames(data)[1]<- "SOIL_DEGR"

# Rescale
data$SOIL_DEGR <- scale010(data$SOIL_DEGR,0)

save.image("../PROCESSED/SOIL_DEGR.Rdata")
