#======================================
# Accessibility data
#======================================

# This script reads and transforms the raw accessibility data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: combination of Percent of paved roads over total roads, Road density, Rail lines density of teh FAO food security dataset.

setwd(data_wd)
## Variable construction for ACCESSIBILITY ##
# 3 components to be read from individual sheets, converted to correct format and combined.

#####  READ AND REFORMAT DATA  ####
## PAVED ROADS
data <- read_excel("ACCESSIBILITY_ORIG.xlsx", sheet = "V_2.1", col_names = TRUE, col_types = NULL,skip = 2)

# Rename badly named columns - Takes the first year of the column name --> hoeft hier niet
# colnames(data)[3:ncol(data)] <- colsplit(colnames(data)[3:ncol(data)], split="-", c("YEAR","TRASH"))[,1]

tdata <- gather(data,YEAR,PAVED_ROADS, `1990`:ncol(data))
data2 <- data.frame(row.names = c(1:nrow(tdata)))
data2$COUNTRY <- tdata$`Regions/Subregions/Countries`
data2$CCODE <- tdata$`FAOST_CODE`
data2$YEAR <- as.character(tdata$YEAR)
data2$PAVED_ROADS <- tdata$PAVED_ROADS

PAVED_ROADS <- data2
rm(data,data2,tdata)

## ROAD DENSITY  

data <- read_excel("ACCESSIBILITY_ORIG.xlsx", sheet = "V_2.2", col_names = TRUE, col_types = NULL,skip = 2)

tdata <- gather(data,YEAR,ROAD_DENSITY, `1990`:ncol(data))
data2 <- data.frame(row.names = c(1:nrow(tdata)))
data2$COUNTRY <- tdata$`Regions/Subregions/Countries`
data2$CCODE <- tdata$`FAOST_CODE`
data2$YEAR <- as.character(tdata$YEAR)
data2$ROAD_DENSITY <- tdata$ROAD_DENSITY

ROAD_DENSITY <- data2
rm(data,data2,tdata)

## RAIL DENSITY

data <- read_excel("ACCESSIBILITY_ORIG.xlsx", sheet = "V_2.3", col_names = TRUE, col_types = NULL,skip = 2)

# Rename badly named columns - Takes the first year of the column name
# colnames(data)[3:ncol(data)] <- colsplit(colnames(data)[3:ncol(data)], split="-", c("YEAR","TRASH"))[,1]

tdata <- gather(data,YEAR,RAIL_DENSITY, `1990`:ncol(data))
data2 <- data.frame(row.names = c(1:nrow(tdata)))
data2$COUNTRY <- tdata$`Regions/Subregions/Countries`
data2$CCODE <- tdata$`FAOST_CODE`
data2$YEAR <- as.character(tdata$YEAR)
data2$RAIL_DENSITY <- tdata$RAIL_DENSITY

RAIL_DENSITY <- data2
rm(data,data2,tdata)


#### TRANFORMATION ####

# T1. PAVED_ROADS

# T1.1 Fill in missing values - PAVED ROADS ####
PAVED_ROADS <- PAVED_ROADS[order(PAVED_ROADS$COUNTRY, PAVED_ROADS$YEAR),]

# T1.2 Merge with ID mat and subset countries of interest --> zorgt er ook voor dat overal van 1989 tot 2014 dataplaatsen zijn
PR <- merge(id_mat, PAVED_ROADS, by.x=c("FAO","YEAR"), by.y=c("CCODE","YEAR"), all.x = T)

# T1.3 Impute missing. Use closest known value
PR <- PR[order(PR$COUNTRY.x, PR$YEAR),]
PR <- flp.impute(PR,1,12)


# T2. ROAD_DENSITY

# T2.1 Fill in missing values - ROAD_DENSITY ####
ROAD_DENSITY <- ROAD_DENSITY[order(ROAD_DENSITY$COUNTRY, ROAD_DENSITY$YEAR),]

# T2.2 Merge with ID mat and subset countries of interest
RoD <- merge(id_mat, ROAD_DENSITY, by.x=c("FAO","YEAR"), by.y=c("CCODE","YEAR"), all.x = T)
RoD <- RoD[order(RoD$COUNTRY.x, RoD$YEAR),]

# T2.3 Impute missing.
RoD<-flp.impute(RoD,1,12)


# T3. RAIL-DENSITY

# T3.1 Fill in missing values - RAIL DENSITY ####
RAIL_DENSITY <- RAIL_DENSITY[order(RAIL_DENSITY$COUNTRY, RAIL_DENSITY$YEAR),]

# T3.2 Merge with ID mat and subset countries of interest
RaD <- merge(id_mat, RAIL_DENSITY, by.x=c("FAO","YEAR"), by.y=c("CCODE","YEAR"), all.x = T)

# T3.3 Impute missing. Use closest known value.
RaD <- RaD[order(RaD$COUNTRY.x, RaD$YEAR),]
RaD <- flp.impute(RaD,1,12)
# zitten verschillende landen hier met NA of geen data voor railroad, maar dat is eig geen probleem, 
# want we nemen hierna toch nog het gemiddelde over de 3 variabelen

rm(PAVED_ROADS,ROAD_DENSITY,RAIL_DENSITY)



#### CREATE ACCESSIBILITY INDEX ####

# Rescale all
PR$PAVED_ROADS <- scale010(PR$PAVED_ROADS,0)
RoD$ROAD_DENSITY <- scale010(RoD$ROAD_DENSITY,0)
RaD$RAIL_DENSITY <- scale010(RaD$RAIL_DENSITY,0)

# Reorder sets
PR <- PR[order(PR$ISO3C, PR$YEAR),]
RoD <- RoD[order(RoD$ISO3C, RoD$YEAR),]
RaD <- RaD[order(RaD$ISO3C, RaD$YEAR),]

# Bind individual variables into one set
ACCESSIBILITY <- as.data.frame(
  cbind(
    PR$YEAR,
    as.character(PR$ISO3C), 
    as.character(PR$COUNTRY.x),
    PR$PAVED_ROADS,
    RoD$ROAD_DENSITY, 
    RaD$RAIL_DENSITY
  )
)

rm(PR,RoD,RaD)

# Rename and correct class
colnames(ACCESSIBILITY) <- c("YEAR","ISO3C","COUNTRY","PR","RoD","RaD")
ACCESSIBILITY$PR <- as.numeric(as.character(ACCESSIBILITY$PR))
ACCESSIBILITY$RoD <- as.numeric(as.character(ACCESSIBILITY$RoD))
ACCESSIBILITY$RaD <- as.numeric(as.character(ACCESSIBILITY$RaD))


# Calculate accessibility index
ACCESSIBILITY$ACCESSIBILITY <- rowMeans(subset(ACCESSIBILITY, select = c(PR,RoD,RaD)),na.rm = TRUE)

#Rescale again so that variable is 0-10 like the other variables
ACCESSIBILITY$ACCESSIBILITY <- scale010(ACCESSIBILITY$ACCESSIBILITY, 0)

data <- subset(ACCESSIBILITY, select = c(ACCESSIBILITY, ISO3C, YEAR))
rm(ACCESSIBILITY)

save.image("../PROCESSED/ACCESSIBILITY.Rdata")








