#======================================
# Food production data
#======================================

# This script reads and transforms the raw food production data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: net per capita food production index number (2004-2006 = 100). The FAO indices of 
# agricultural production show the relative level of the aggregate volume of agricultural production 
# for each year in comparison with the base period 2004-2006. They are based on the sum of price-weighted 
# quantities of different agricultural commodities produced after deductions of quantities used as seed and 
# feed weighted in a similar manner. The resulting aggregate represents, therefore, disposable production for 
# any use except as seed and feed.

setwd(data_wd)

#### Var construction - FOOD_PROD ####
# Data
data <- read.csv('FOOD_PROD_ORIG.csv')
data <- subset(data,select = c("Area.Code","Area","Year","Value"))
data$Area <- as.character(data$Area)

# Load ID matrix and merge to subset wanted info
mdata <- merge(id_mat, data, by.x = c("FAO","YEAR"), by.y = c("Area.Code","Year"), all.x=T)

# Impute first and last values if any are missing by repeating the first or last available data point
mdata <- flp.impute(mdata,1,12)

data <- subset(mdata, select = c("Value","YEAR","ISO3C"))
rm(mdata)
colnames(data)[1]<- "FOOD_PROD"

# Rescale
data$FOOD_PROD <- scale010(data$FOOD_PROD,0)

save.image("../PROCESSED/FOOD_PROD.Rdata")
