#======================================
# Water resources per capita data
#======================================

# This script reads and transforms the raw water resources per capita data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: Renewable internal freshwater resources per capita (cubic meters), Renewable internal freshwater resources flows refer to internal renewable resources (internal river flows and groundwater from rainfall) in the country. Renewable internal freshwater resources per capita are calculated using the World Bank's population estimates.

setwd(data_wd)
#### Read data ####
data <- read_excel("WATER_RES_PER_CAP_ORIG.xls", sheet = "Data", col_names = TRUE, col_types = NULL,skip = 3,na="")

# Fix names - Splits the names and extracts only the numeric year
#colnames(data)[4:ncol(data)] <- colsplit(colnames(data)[4:ncol(data)], split="SOC.", c("TRASH","YEAR"))[,2]

# Gather to country-year units and give the new variable/columnname WATER_RES_PER_CAP
tdata <- gather(data,YEAR,WATER_RES_PER_CAP, `1960`:ncol(data))

data2 <- data.frame(row.names = c(1:nrow(tdata)))
data2$COUNTRY <- tdata$`Country Name`
data2$ISO <- tdata$`Country Code`
data2$YEAR <- as.character(tdata$YEAR)
data2$WATER_RES_PER_CAP <- tdata$WATER_RES_PER_CAP

WATER_RES_PER_CAP <- data2
rm(data,data2,tdata)

#### Bind to id_mat #### (Merging by ISO)

# Merging by ISO, so rename those that don't match
# ik denk niet dat er zijn die niet matchen...

# Merge
mdata <- merge(id_mat, WATER_RES_PER_CAP, by.x = c("ISO3C","YEAR"), by.y = c("ISO","YEAR"), all.x=T) # all.x=T zorgt voor een left (outer) join, zodat alleen de jaartallen die in GCRI zitten (1998-2014) meegenomen workden

#### Missing values ####
# Impute using previous known values
mdata <- flp.impute(mdata, 1, 12)

# Rescale from 0 to 10 with possibility of swopping order high to low
mdata$WATER_RES_PER_CAP <- scale010(mdata$WATER_RES_PER_CAP,0) #direction == 0, no direction change

### Final dataset for further use ###

data <- subset(mdata,select = c("WATER_RES_PER_CAP","YEAR","ISO3C"))

rm(mdata, WATER_RES_PER_CAP)
save.image("../PROCESSED/WATER_RES_PER_CAP.Rdata")