#======================================
# Water withdrawal data
#======================================

# This script reads and transforms the raw water withdrawal data into the Rdata file found in the folder PROCESSED_DATA

# the data contains: Annual freshwater withdrawals, total (% of internal resources), Annual freshwater withdrawals refer to total water withdrawals, not counting evaporation losses from storage basins. Withdrawals also include water from desalination plants in countries where they are a significant source. Withdrawals can exceed 100 percent of total renewable resources where extraction from nonrenewable aquifers or desalination plants is considerable or where there is significant water reuse. Withdrawals for agriculture and industry are total withdrawals for irrigation and livestock production and for direct industrial use (including withdrawals for cooling thermoelectric plants). Withdrawals for domestic uses include drinking water, municipal use or supply, and use for public services, commercial establishments, and homes. Data are for the most recent year available for 1987-2002.

setwd(data_wd)
#### Read data ####
data <- read_excel("WATER_WITHDR_ORIG.xls", sheet = "Data", col_names = TRUE, col_types = NULL,skip = 3,na="")

# Fix names - Splits the names and extracts only the numeric year
#colnames(data)[4:ncol(data)] <- colsplit(colnames(data)[4:ncol(data)], split="SOC.", c("TRASH","YEAR"))[,2]

# Gather to country-year units and give the new variable/columnname WATER_WITHDR
tdata <- gather(data,YEAR,WATER_WITHDR, `1960`:ncol(data))

data2 <- data.frame(row.names = c(1:nrow(tdata)))
data2$COUNTRY <- tdata$`Country Name`
data2$ISO <- tdata$`Country Code`
data2$YEAR <- as.character(tdata$YEAR)
data2$WATER_WITHDR <- tdata$WATER_WITHDR

WATER_WITHDR <- data2
rm(data,data2,tdata)

#### Bind to id_mat #### (Merging by ISO)

# Merging by ISO, so rename those that don't match
# ik denk niet dat er zijn die niet matchen...

# Merge
mdata <- merge(id_mat, WATER_WITHDR, by.x = c("ISO3C","YEAR"), by.y = c("ISO","YEAR"), all.x=T) # all.x=T zorgt voor een left (outer) join, zodat alleen de jaartallen die in GCRI zitten (1998-2014) meegenomen workden

#### Missing values ####
# Impute using previous known values
mdata <- flp.impute(mdata, 1, 12)

# Rescale from 0 to 10 with possibility of swopping order high to low
mdata$WATER_WITHDR <- scale010(mdata$WATER_WITHDR,0) #direction == 0, no direction change

### Final dataset for further use ###

data <- subset(mdata,select = c("WATER_WITHDR","YEAR","ISO3C"))

rm(mdata, WATER_WITHDR)
save.image("../PROCESSED/WATER_WITHDR.Rdata")